from enum import Enum


class Attributes(Enum):
    Y_TRUE = "Y_true"
    RUNS = "Rows"
    CADDO_FILE_SETTINGS = "Caddo_file_settings"
    X_RAW = "X_raw"
    Y_RAW = "Y_raw"
    X = "X"
    Y = "Y"
    MODEL = "Model"
