class Settings:
    input_data_file = ''
    model_initializer_module_path = ''
    data_preprocessor_module_path = ''
    model_trainer_module_path = ''
    model_tester_module_path = ''
    model_evaluator_module_path = ''
